@@ -36,7 +36,7 @@
   Returns the name of the generated child object.
  */
 
-static bool createdCentralWidget = FALSE;
+static bool createdCentralWidget = false;
 
 TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentClass, const TQString& par, const TQString& layout )
 {
@@ -44,7 +44,7 @@ TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentCla
     if ( parent == "self" && isMainWindow ) {
 	if ( !createdCentralWidget )
 	    out << indent << "self.setCentralWidget(TQWidget(self,\"tqt_central_widget\"))" << endl;
-	createdCentralWidget = TRUE;
+	createdCentralWidget = true;
 	parent = "self.centralWidget()";
     }
     TQDomElement n;
@@ -116,7 +116,7 @@ TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentCla
 
     lastItem = "None";
     // set the properties and insert items
-    bool hadFrameShadow = FALSE;
+    bool hadFrameShadow = false;
     for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
 	if ( n.tagName() == "property" ) {
 	    bool stdset = stdsetdef;
@@ -131,7 +131,7 @@ TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentCla
 	    if ( prop == "name" )
 		continue;
 	    if ( isLine && prop == "frameShadow" )
-		hadFrameShadow = TRUE;
+		hadFrameShadow = true;
 	    if ( prop == "buddy" && value.startsWith("\"") && value.endsWith("\"") ) {
 		buddies << Buddy( objName, value.mid(1, value.length() - 2 ) );
 		continue;
@@ -584,12 +584,12 @@ TQString Uic::setObjectProperty( const TQString& objClass, const TQString& obj,
 	    TQString palette = "pal";
 	    if ( !pal_used ) {
 		out << indent << palette << " = TQPalette()" << endl;
-		pal_used = TRUE;
+		pal_used = true;
 	    }
 	    TQString cg = "cg";
 	    if ( !cg_used ) {
 		out << indent << cg << " = TQColorGroup()" << endl;
-		cg_used = TRUE;
+		cg_used = true;
 	    }
 	    n = e.firstChild().toElement();
 	    while ( !n.isNull() && n.tagName() != "active" )
